//    QtLockscreen
//    Copyright (C) 2011 Paolo Iommarini
//    sakya_tg@yahoo.it
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#ifndef LSWIDGETS_H
#define LSWIDGETS_H

#include "lswidget.h"
#include "lsbutton.h"
#include "lsdatetime.h"
#include "lsunlockbutton.h"
#include "lsrect.h"
#include "lsbattery.h"
#include "lsmediaplaypausebutton.h"
#include "lsmedianextbutton.h"
#include "lsmediapreviousbutton.h"
#include "lsmediametadata.h"
#include "lsmediaalbumart.h"
#include "lsmediatimelabel.h"
#include "lsimage.h"
#include "lscommandbutton.h"
#include "lsnotification.h"
#include "lsslidetounlock.h"
#include "lstext.h"
#include "lsweather.h"
#include "lswifi.h"

#endif // LSWIDGETS_H
